@@ -3,6 +3,7 @@ import json
 
 from powerx_energy_api import config
 from powerx_energy_api import exceptions
+import random
 
 class UserAPI():
 
@@ -41,9 +42,12 @@ class UserAPI():
             data = json.loads(x.text)
             unit = customer_info['preferences']['temperature_unit']
             data['summary']['avg']=data['summary']['avg_celsius']
+
             if unit=='fahrenheit':
                 data['summary']['avg']=data['summary']['avg_fahrenheit']
             data['summary']['unit']=unit    
+            data['summary']['avg']=random.randint(0,10)
+            print(f"random number is {data['summary']['avg']}")
             return data,200
         except requests.exceptions.ConnectionError:
             raise exceptions.ConnectionError        
@@ -83,4 +87,4 @@ class UserAPI():
    
 if __name__ == "__main__":
     api = UserAPI()
-    api.login('username','password')
\ No newline at end of file
+    api.get_current_heat('manuel@powerx.co','test123')
\ No newline at end of file
